﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Net;
using System.IO;
using System.Windows.Forms;

namespace PdfEncrypter
{
    public class UpdateHelper
    {
        private static System.ComponentModel.BackgroundWorker bwCheckVersion = new System.ComponentModel.BackgroundWorker();

        public static void InitializeCheckVersion()
        {
            bwCheckVersion.WorkerReportsProgress = true;
            bwCheckVersion.DoWork += bwCheckVersion_DoWork;
            bwCheckVersion.RunWorkerCompleted += bwCheckVersion_RunWorkerCompleted;
            bwCheckVersion.ProgressChanged += bwCheckVersion_ProgressChanged;

            bwCheckVersion.RunWorkerAsync();
        }

        static void bwCheckVersion_ProgressChanged(object sender, System.ComponentModel.ProgressChangedEventArgs e)
        {
            CheckVersionResult res = (CheckVersionResult)e.UserState;

            if (res.OutputMessage != String.Empty)
            {
                if (!res.NewVersionReleased)
                {
                    Module.ShowMessage(res.OutputMessage);
                }
                else
                {
                    DialogResult resq = Module.ShowQuestionDialogYesFocus(TranslateHelper.Translate("A new version has been released. Would you like to download it now ?"), TranslateHelper.Translate("Download new version ?"));
                    if (resq == DialogResult.Yes)
                    {
                        System.Diagnostics.Process.Start(Module.DownloadURL);
                    }
                }
            }
        }

        static void bwCheckVersion_RunWorkerCompleted(object sender, System.ComponentModel.RunWorkerCompletedEventArgs e)
        {
            
        }

        static void bwCheckVersion_DoWork(object sender, System.ComponentModel.DoWorkEventArgs e)
        {
            CheckVersionResult res = CheckVersionBackground();

            bwCheckVersion.ReportProgress(100, res);
        }
        public static CheckVersionResult CheckVersionBackground()
        {
            bool onstart = true;
            CheckVersionResult res = new CheckVersionResult();

            try
            {
                string str = DownloadPage("http://www.4dots-software.com/versions.txt");

                if (str != "Error" && str != String.Empty)
                {
                    StringReader sr = new StringReader(str);
                    string line;

                    bool found = false;

                    while ((line = sr.ReadLine()) != null)
                    {
                        int epos = line.IndexOf("=");

                        string title = line.Substring(0, epos);
                        string version = line.Substring(epos + 1, line.Length - epos - 1);

                        string app = title + " V" + version;

                        if (Module.ShortApplicationTitle.StartsWith(title) && app != Module.ShortApplicationTitle)
                        {
                            found = true;
                            res.OutputMessage = TranslateHelper.Translate("A new version has been released. Press the OK button to download the new version");
                            res.NewVersionReleased = true;

                            //System.Diagnostics.Process.Start(Module.DownloadURL);
                        }
                        else if (Module.ShortApplicationTitle.StartsWith(title))
                        {
                            found = true;
                            if (!onstart)
                            {
                                res.OutputMessage = TranslateHelper.Translate("This is the latest version !");
                            }
                        }
                    }

                    if (!found)
                    {
                        if (!onstart)
                        {
                            res.OutputMessage = TranslateHelper.Translate("An error occured !");
                        }
                    }
                }
                else
                {
                    if (!onstart)
                    {
                        res.OutputMessage = TranslateHelper.Translate("An error occured !");
                    }
                }
            }
            catch
            {
                if (!onstart)
                {
                    res.OutputMessage = TranslateHelper.Translate("An error occured !");
                }
            }

            return res;
        }

        public static string DownloadPage(string uri)
        {
            try
            {
                WebClient client = new WebClient();

                Stream data = client.OpenRead(uri);
                StreamReader reader = new StreamReader(data);
                string s = reader.ReadToEnd();
                data.Close();
                reader.Close();
                return s;
            }
            catch (Exception ex)
            {
                return "Error";
            }
        }

        public static void CheckVersion(bool onstart)
        {
            try
            {
                string str = DownloadPage("http://www.4dots-software.com/versions.txt");

                if (str != "Error" && str != String.Empty)
                {
                    StringReader sr = new StringReader(str);
                    string line;

                    bool found = false;

                    while ((line = sr.ReadLine()) != null)
                    {
                        int epos = line.IndexOf("=");

                        string title = line.Substring(0, epos);
                        string version = line.Substring(epos + 1, line.Length - epos - 1);

                        string app = title + " V" + version;

                        if (Module.ShortApplicationTitle.StartsWith(title) && app != Module.ShortApplicationTitle)
                        {
                            found = true;
                            Module.ShowMessage("A new version has been released. Press the OK button to download the new version");

                            System.Diagnostics.Process.Start(Module.DownloadURL);
                        }
                        else if (Module.ShortApplicationTitle.StartsWith(title))
                        {
                            found = true;
                            if (!onstart)
                            {
                                Module.ShowMessage("This is the latest version !");
                            }
                        }
                    }

                    if (!found)
                    {
                        if (!onstart)
                        {
                            Module.ShowMessage("An error occured !");
                        }
                    }
                }
                else
                {
                    if (!onstart)
                    {
                        Module.ShowMessage("An error occured !");
                    }
                }
            }
            catch
            {
                if (!onstart)
                {
                    Module.ShowMessage("An error occured !");
                }
            }
        }
    }

    public class CheckVersionResult
    {
        public bool NewVersionReleased = false;
        public string OutputMessage = "";
    }
}
